"""
name : v_icom_vars.py IC705
last edited: 20240311
Copyright : DK1RI
If no other earlier rights are affected, this program can be used under GPL (Gnu public licence)
Specific constants and variables
"""
# configurable variables (default) may be overwritten by ___config_default
device_name = "IC705"
device_number = 1
terminal_activ = 1
telnet_active = 1
telnet_port = 23
comportnumber = 5
comport = "COM5"
civ_address = 0xA4
control_data_in = "/xampp/htdocs/usb_interface/from_web"
control_data_out = "/xampp/htdocs/usb_interface/to_web"
# country of radio
country = 0
radio_version = 0

# system configuration varialbles (default)
config_file_default = "___config_default"
config_file = "___config"
announce_list = "___announcements"
log_file = "___logfile"
logfilesize = 100               # lines
command_timeout = 10            # seconds waittime between keystrokes
civ_watchdog_timeout = 1        # seconds
test_mode = 1
last_memory = 0

# other
ok_msg = bytearray([0xfe, 0xfe, 0xe0, civ_address, 0xfb, 0xfd])
nok_msg = bytearray([0xfe, 0xfe, 0xe0, civ_address, 0xfa, 0xfd])
Civ_out = bytearray([])
Civ_in = bytearray([])
command_no = 1
error_cmd_no = 255
last_error_msg = ""
command_time = 0
civ_watchdog_time = 0
civ_command_length = 0
# set to 1, when read is done; to 0 after successful send (SK)
input_locked = 0
last_frequency = 0
last_memory_group = 0
last_vfo_mem = 0    # 0: VFOA, 1:VFOB, 3: memory
vfo_split = 0
command_at_start = 1
icom_usb = 0
data_to_device = bytearray([])
data_to_CR = bytearray([])
start_echo_off = bytearray([0xfe, 0xfe, civ_address, 0xe0, 0x1a, 0x05, 0x01, 0x32, 0x00, 0xfd])
start_transceive = bytearray([0xfe, 0xfe, civ_address, 0xe0, 0x1a, 0x05, 0x01, 0x31, 0x01, 0xfd])
start_memory_no = bytearray([0xfe, 0xfe, civ_address, 0xe0, 0x08, 0x00, 0x00, 0xfd])
start_memory_write = bytearray([0xfe, 0xfe, civ_address, 0xe0, 0x09, 0xfd])
start_VFOA = bytearray([0xfe, 0xfe, civ_address, 0xe0, 0x07, 0x00, 0xfd])
start_read_f = bytearray([0xfe, 0xfe, civ_address, 0xe0, 0x03, 0xfd])
start_read_mode = bytearray([0xfe, 0xfe, civ_address, 0xe0, 0x04, 0xfd])
start_read_data_mode = bytearray([0xfe, 0xfe, civ_address, 0xe0, 0x1a, 0x06, 0xfd])
# start of tokens for read memorycontents
# the structure is identical for all radios (but n split for 9700)
# so the token must not be set differnet for different radios
start_token_for_memory_read = 0x0174


"""
ask_content used by commands which require preceding answer command (memory and copy_band_stack)

idle: 
ask_content = 0

operate command:
0: the operate command will generate ask command and set ask_content to 1. copy sk input to lastcommand
1: wait until got the corresponding answer is completed; copy data to answer_storage, set ask_content to 2
2: get command from lastcommand -> modify, send command and set ask_content to 0

answer command:
0: answercommand_memory will generate ask command and set ask_content to 4. do not keep sk input 
answerfunction will send answer to SK and set ask_content set to 0

99: used for anwer memory_raw
"""
ask_content = 0
answer_storage = bytearray([])      # written by anwser, used by next command for ask_content > 0
command_storage = bytearray([])     # written by command, used by next answer


span_center_mode = {0: [0x00, 0x25, 0x00, 0x00, 0x00, 0xfd],
                    1: [0x00, 0x50, 0x00, 0x00, 0x00, 0xfd],
                    2: [0x00, 0x00, 0x01, 0x00, 0x00, 0xfd],
                    3: [0x00, 0x50, 0x02, 0x00, 0x00, 0xfd],
                    4: [0x00, 0x00, 0x05, 0x00, 0x00, 0xfd],
                    5: [0x00, 0x00, 0x10, 0x00, 0x00, 0xfd],
                    6: [0x00, 0x00, 0x25, 0x00, 0x00, 0xfd],
                    7: [0x00, 0x00, 0x50, 0x00, 0x00, 0xfd],
                    }


# some command need frequency range numbers
tokennumber_frequency_range_number =   {785: 1,
                                        786: 1,
                                        787: 2,
                                        788: 2,
                                        789: 3,
                                        790: 3,
                                        791: 4,
                                        792: 4,
                                        793: 5,
                                        794: 5,
                                        795: 6,
                                        796: 6,
                                        797: 7,
                                        798: 7,
                                        799: 8,
                                        800: 8,
                                        801: 9,
                                        802: 9,
                                        803: 10,
                                        804: 10,
                                        805: 11,
                                        806: 11,
                                        807: 12,
                                        808: 12,
                                        809: 13,
                                        810: 13,
                                        811: 14,
                                        812: 14,
                                        813: 15,
                                        814: 15,
                                        815: 16,
                                        816: 16,
                                        817: 17,
                                        818: 17,
                                        }

# Bandedges for the frequency ranges
number_frequency_range =       {1:[30, 1600],
                                2: [1600, 2000],
                                3: [2000, 6000],
                                4: [6000, 8000],
                                5: [8000, 11000],
                                6: [11000, 15000],
                                7: [15000, 20000],
                                8: [20000, 22000],
                                9: [22000, 26000],
                                10: [26000, 30000],
                                11: [30000, 45000],
                                12: [45000, 60000],
                                13: [60000, 74800],
                                14: [74800, 108000],
                                15: [108000, 137000],
                                16: [137000, 200000],
                                17: [400000, 4700000],
                                }


user_band_edge ={                0:[1810, 1999],
                                1:[3500, 3800],
                                2:[7000, 7100],
                                3:[10100, 10150],
                                4:[14000, 14350],
                                5:[18068, 18168],
                                6:[21000, 21450],
                                7:[24890, 24990],
                                8:[28000, 297000],
                                9:[50000810, 52000],
                                10: [144000, 146000],
                                11: [430000, 440000],
                                 }


# civcodes of chanal 4 of scope band edges
number_civcommand_chanal4 ={    785:[0x03, 0x69],
                                787: [0x03, 0x70],
                                789: [0x03, 0x71],
                                791: [0x03, 0x72],
                                793: [0x03, 0x73],
                                795: [0x03, 0x74],
                                797: [0x03, 0x75],
                                799: [0x03, 0x76],
                                801: [0x03, 0x77],
                                803: [0x03, 0x78],
                                805: [0x03, 0x79],
                                807: [0x03, 0x80],
                                809: [0x03, 0x81],
                                811: [0x03, 0x82],
                                813: [0x03, 0x83],
                                815: [0x03, 0x84],
                                817: [0x03, 0x85],
                                }


gps_sympbol_translate={         0: [0x2F,0x21],
                                1: [0x2F,0x23],
                                2: [0x2F,0x26],
                                3: [0x2F,0x27],
                                4: [0x2F,0x2B],
                                5: [0x2F,0x2D],
                                6: [0x2F,0x2E],
                                7: [0x2F,0x2F],
                                8: [0x2F,0x3A],
                                9: [0x2F,0x3B],
                                10: [0x2F,0x3C],
                                11: [0x2F,0x3D],
                                12: [0x2F,0x3E],
                                13: [0x2F,0x43],
                                14: [0x2F,0x45],
                                15: [0x2F,0x4B],
                                16: [0x2F,0x4C],
                                17: [0x2F,0x4F],
                                18: [0x2F,0x50],
                                19: [0x2F,0x52],
                                20: [0x2F,0x53],
                                21: [0x2F,0x54],
                                22: [0x2F,0x55],
                                23: [0x2F,0x56],
                                24: [0x2F,0x57],
                                25: [0x2F,0x58],
                                26: [0x2F,0x59],
                                27: [0x2F,0x5B],
                                28: [0x2F,0x5C],
                                29: [0x2F,0x5E],
                                30: [0x2F,0x5F],
                                31: [0x2F,0x60],
                                32: [0x2F,0x61],
                                33: [0x2F,0x62],
                                34: [0x2F,0x66],
                                35: [0x2F,0x67],
                                36: [0x2F,0x68],
                                37: [0x2F,0x6a],
                                38: [0x2F,0x6b],
                                39: [0x2F,0x6e],
                                40: [0x2F,0x70],
                                41: [0x2F,0x72],
                                42: [0x2F,0x73],
                                43: [0x2F,0x75],
                                44: [0x2F,0x76],
                                45: [0x2F,0x79],
                                46: [0x2F,0x23],
                                47: [0x5C,0x26],
                                48: [0x5C,0x2D],
                                49: [0x5C,0x2E],
                                50: [0x5C,0x30],
                                51: [0x5C,0x3B],
                                52: [0x5C,0x3E],
                                53: [0x5C,0x4C],
                                54: [0x5C,0x53],
                                55: [0x5C,0x55],
                                56: [0x5C,0x57],
                                57: [0x5C,0x59],
                                58: [0x5C,0x5E],
                                59: [0x5C,0x5F],
                                60: [0x5C,0x61],
                                61: [0x5C,0x63],
                                62: [0x5C,0x67],
                                63: [0x5C,0x68],
                                64: [0x5C,0x6A],
                                65: [0x5C,0x6D],
                                66: [0x5C,0x6E],
                                67: [0x5C,0x6F],
                                68: [0x5C,0x73],
                                69: [0x5C,0x74],
                                70: [0x5C,0x75],
                                71: [0x5C,0x76],
                                72: [0x5C,0x78],
                                73: [0x2f,0x22],
                                }


# Translation of comandtoken to coresponding CIV code:
# used for 1byte parameters
# different civ_subcommand within a sk_command must be handled like parameters !!
#
# 0 parameter or u_command1 or not used (if special program used or parameter or subcommand has gaps eg):
# country, length of_sk_command, 0, civ_command, civ_subcommand, [civ_subcommand[, civ_subcommand]]
#
# 1 parameter:
# country, length of_sk_command, 1, conversion, max_value1, adder1, civ_command, civ_subcommand, [civ_subcommand[, civ_subcommand]]
#
# 2 parameters:
#  country, length of_sk_command, 2, conversion, max_value1, adder1, max_value2, adder2, civ_command, civ_subcommand, [civ_subcommand[, civ_subcommand]]
#
#  3 parameters:
#  country, length of_sk_command, 3, conversion, max_value1, adder2, max_value1, adder2, max_value3, adder3, civ_command, civ_subcommand, [civ_subcommand[, civ_subcommand]]
#
# 1 two byte parameter
# country, length of_sk_command, 9, conversion, max_value_high byte, max_value_low byte, adder, civ_command, civ_subcommand, [civ_subcommand[, civ_subcommand]]
#
# set a value (0 parameter):
# country, length of_sk_command, 10, value, civ_command, civ_subcommand, [civ_subcommand[, civ_subcommand]]
#
# one string parameter ) 0 other parameter:
# country, max_length_of_string, 11, alphabet, civ_command, civ_subcommand, [civ_subcommand[, civ_subcommand]]
#
# country: 0: all, 1: US only
# alphabet:
#
#
# conversion; 0: binary, 1: to 1 byte BCD, 2: to 2byte BCD 3: add 255 to maxvalue 4: to 3 byte BCD
#
token_civ_code =   {256: bytearray([0, 5, 0, 0x05]),
                    257: bytearray([0, 2, 0, 0x03]),
                    258: bytearray([0, 3, 0, 0x06]),
                    259: bytearray([0, 2, 0, 0x04]),
                    260: bytearray([0, 2, 0, 0x02]),
                    261: bytearray([0, 2, 0, 0x07]),
                    262: bytearray([0, 3, 0, 0x07]),
                    263: bytearray([0, 3, 0, 0x08, 0xA0]),
                    264: bytearray([0, 3, 0, 0x08, 0xA0]),
                    265: bytearray([0, 3, 0, 0x09]),
                    266: bytearray([0, 6, 0, 0x0d]),
                    267: bytearray([0, 2, 0, 0x0c]),
                    268: bytearray([0, 3, 0, 0x0e]),
                    269: bytearray([0, 3, 1, 0, 6, 161, 0x0e]),
                    270: bytearray([0, 2, 0, 0x0e, 0xb0]),
                    271: bytearray([0, 3, 1, 0, 2, 1, 0x0e, 0xb1]),
                    272: bytearray([0, 3, 1, 0, 3, 0, 0x0e, 0xb2]),
                    273: bytearray([0, 3, 0, 0x0e]),
                    274: bytearray([0, 3, 0, 0x0f]),
                    275: bytearray([0, 2, 0, 0x0f]),
                    276: bytearray([0, 3, 1, 1, 13, 0, 0x10]),
                    277: bytearray([0, 2, 0, 0x10]),
                    278: bytearray([0, 3, 0, 0x11]),
                    279: bytearray([0, 2, 0, 0x11]),
                    280: bytearray([0, 3, 1, 0, 3, 0, 0x13]),
                    281: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x01]),
                    282: bytearray([0, 2, 0, 0x14, 0x01]),
                    283: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x02]),
                    284: bytearray([0, 2, 0, 0x14, 0x02]),
                    285: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x03]),
                    286: bytearray([0, 2, 0, 0x14, 0x03]),
                    287: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x06]),
                    288: bytearray([0, 2, 0, 0x14, 0x06]),
                    289: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x07]),
                    290: bytearray([0, 2, 0, 0x14, 0x07]),
                    291: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x08]),
                    292: bytearray([0, 2, 0, 0x14, 0x08]),
                    293: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x09]),
                    294: bytearray([0, 2, 0, 0x14, 0x09]),
                    295: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x0a]),
                    296: bytearray([0, 2, 0, 0x14, 0x0a]),
                    297: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x0b]),
                    298: bytearray([0, 2, 0, 0x14, 0x0b]),
                    299: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x0c]),
                    300: bytearray([0, 2, 0, 0x14, 0x0c]),
                    301: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x0d]),
                    302: bytearray([0, 2, 0, 0x14, 0x0d]),
                    303: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x0e]),
                    304: bytearray([0, 2, 0, 0x14, 0x0e]),
                    305: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x0f]),
                    306: bytearray([0, 2, 0, 0x14, 0x0f]),
                    307: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x12]),
                    308: bytearray([0, 2, 0, 0x14, 0x12]),
                    309: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x15]),
                    310: bytearray([0, 2, 0, 0x14, 0x15]),
                    311: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x16]),
                    312: bytearray([0, 2, 0, 0x14, 0x16]),
                    313: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x17]),
                    314: bytearray([0, 2, 0, 0x14, 0x17]),
                    315: bytearray([0, 3, 1, 2, 255, 0, 0x14, 0x19]),
                    316: bytearray([0, 2, 0, 0x14, 0x19]),
                    317: bytearray([0, 2, 0, 0x15, 0x01]),
                    318: bytearray([0, 2, 0, 0x15, 0x02]),
                    319: bytearray([0, 2, 0, 0x15, 0x05]),
                    320: bytearray([0, 2, 0, 0x15, 0x11]),
                    321: bytearray([0, 2, 0, 0x15, 0x12]),
                    322: bytearray([0, 2, 0, 0x15, 0x13]),
                    323: bytearray([0, 2, 0, 0x15, 0x14]),
                    324: bytearray([0, 2, 0, 0x15, 0x15]),
                    325: bytearray([0, 2, 0, 0x15, 0x16]),
                    326: bytearray([0, 3, 1, 0, 2, 0, 0x16, 0x02]),
                    327: bytearray([0, 2, 0, 0x16, 0x02]),
                    328: bytearray([0, 3, 1, 0, 2, 1, 0x16, 0x12]),
                    329: bytearray([0, 2, 0, 0x16, 0x12]),
                    330: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x22]),
                    331: bytearray([0, 2, 0, 0x16, 0x22]),
                    332: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x40]),
                    333: bytearray([0, 2, 0, 0x16, 0x40]),
                    334: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x41]),
                    335: bytearray([0, 2, 0, 0x16, 0x41]),
                    336: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x42]),
                    337: bytearray([0, 2, 0, 0x16, 0x42]),
                    338: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x43]),
                    339: bytearray([0, 2, 0, 0x16, 0x43]),
                    340: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x44]),
                    341: bytearray([0, 2, 0, 0x16, 0x44]),
                    342: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x45]),
                    343: bytearray([0, 2, 0, 0x16, 0x45]),
                    344: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x46]),
                    345: bytearray([0, 2, 0, 0x16, 0x46]),
                    346: bytearray([0, 3, 1, 0, 2, 0, 0x16, 0x47]),
                    347: bytearray([0, 2, 0, 0x16, 0x47]),
                    348: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x48]),
                    349: bytearray([0, 2, 0, 0x16, 0x48]),
                    350: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x4b]),
                    351: bytearray([0, 2, 0, 0x16, 0x4b]),
                    352: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x4f]),
                    353: bytearray([0, 2, 0, 0x16, 0x4f]),
                    354: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x50]),
                    355: bytearray([0, 2, 0, 0x16, 0x50]),
                    356: bytearray([0, 3, 1, 0, 1, 0, 0x16, 0x56]),
                    357: bytearray([0, 2, 0, 0x16, 0x56]),
                    358: bytearray([0, 3, 1, 0, 2, 0, 0x16, 0x57]),
                    359: bytearray([0, 2, 0, 0x16, 0x57]),
                    360: bytearray([0, 3, 1, 0, 2, 0, 0x16, 0x58]),
                    361: bytearray([0, 2, 0, 0x16, 0x58]),
                    362: bytearray([0, 3, 1, 0, 2, 0, 0x16, 0x5b]),
                    363: bytearray([0, 2, 0, 0x16, 0x5b]),
                    364: bytearray([0, 3, 1, 0, 2, 0, 0x16, 0x5c]),
                    365: bytearray([0, 2, 0, 0x16, 0x5c]),
                    366: bytearray([0, 2, 0, 0x16, 0x5d]),
                    367: bytearray([0, 2, 0, 0x16, 0x5d]),
                    368: bytearray([0, 30, 11, 3, 0x17]),
                    369: bytearray([0, 3, 1, 0, 1, 0, 0x18]),
                    370: bytearray([0, 2, 0, 0x19, 0x00]),
                    371: bytearray([0, 110, 0, 0x1a, 0x00]),
                    372: bytearray([0, 3, 0, 0x1a, 0x00]),
                    373: bytearray([0, 7, 0, 0x1a, 0x00]),
                    374: bytearray([0, 4, 0, 0x1a, 0x00]),
                    375: bytearray([0, 6, 0, 0x1a, 0x00]),
                    376: bytearray([0, 4, 0, 0x1a, 0x00]),
                    377: bytearray([0, 6, 0, 0x1a, 0x00]),
                    378: bytearray([0, 4, 0, 0x1a, 0x00]),
                    379: bytearray([0, 5, 0, 0x1a, 0x00]),
                    380: bytearray([0, 4, 0, 0x1a, 0x00]),
                    381: bytearray([0, 6, 0, 0x1a, 0x00]),
                    382: bytearray([0, 4, 0, 0x1a, 0x00]),
                    383: bytearray([0, 5, 0, 0x1a, 0x00]),
                    384: bytearray([0, 4, 0, 0x1a, 0x00]),
                    385: bytearray([0, 5, 0, 0x1a, 0x00]),
                    386: bytearray([0, 4, 0, 0x1a, 0x00]),
                    387: bytearray([0, 5, 0, 0x1a, 0x00]),
                    388: bytearray([0, 4, 0, 0x1a, 0x00]),
                    389: bytearray([0, 6, 0, 0x1a, 0x00]),
                    390: bytearray([0, 4, 0, 0x1a, 0x00]),
                    391: bytearray([0, 5, 0, 0x1a, 0x00]),
                    392: bytearray([0, 4, 0, 0x1a, 0x00]),
                    393: bytearray([0, 7, 0, 0x1a, 0x00]),
                    394: bytearray([0, 4, 0, 0x1a, 0x00]),
                    395: bytearray([0, 4, 0, 0x1a, 0x00]),
                    396: bytearray([0, 4, 0, 0x1a, 0x00]),
                    397: bytearray([0, 4, 0, 0x1a, 0x00]),
                    398: bytearray([0, 4, 0, 0x1a, 0x00]),
                    399: bytearray([0, 4, 0, 0x1a, 0x00]),
                    400: bytearray([0, 4, 0, 0x1a, 0x00]),
                    401: bytearray([0, 4, 0, 0x1a, 0x00]),
                    402: bytearray([0, 4, 0, 0x1a, 0x00]),
                    403: bytearray([0, 4, 0, 0x1a, 0x01]),
                    404: bytearray([0, 4, 0, 0x1a, 0x01]),
                    405: bytearray([0, 3, 0, 0x1a, 0x02]),
                    406: bytearray([0, 3, 1, 0, 8, 1, 0x1a, 0x02]),
                    407: bytearray([0, 3, 1, 0, 50, 0, 0x1a, 0x03]),
                    408: bytearray([0, 2, 0, 0x1a, 0x03]),
                    409: bytearray([0, 3, 1, 0, 32, 0, 0x1a, 0x03]),
                    410: bytearray([0, 2, 0, 0x1a, 0x03]),
                    411: bytearray([0, 3, 1, 0, 41, 0, 0x1a, 0x03]),
                    412: bytearray([0, 2, 0, 0x1a, 0x03]),
                    413: bytearray([0, 3, 1, 1, 13, 0, 0x1a, 0x04]),
                    414: bytearray([0, 2, 0, 0x1a, 0x04]),
                    415: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x01]),
                    416: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x01]),
                    417: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x02]),
                    418: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x02]),
                    419: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x03]),
                    420: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x03]),
                    421: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x04]),
                    422: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x04]),
                    423: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x05]),
                    424: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x05]),
                    425: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x06]),
                    426: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x06]),
                    427: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x07]),
                    428: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x07]),
                    429: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x08]),
                    430: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x08]),
                    431: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x09]),
                    432: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x09]),
                    433: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x10]),
                    434: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x10]),
                    435: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x11]),
                    436: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x11]),
                    437: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x12]),
                    438: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x12]),
                    439: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x13]),
                    440: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x13]),
                    441: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x14]),
                    442: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x14]),
                    443: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x15]),
                    444: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x15]),
                    445: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x16]),
                    446: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x16]),
                    447: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x17]),
                    448: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x17]),
                    449: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x18]),
                    450: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x18]),
                    451: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x19]),
                    452: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x19]),
                    453: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x20]),
                    454: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x20]),
                    455: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x21]),
                    456: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x21]),
                    457: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x22]),
                    458: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x22]),
                    459: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x23]),
                    460: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x23]),
                    461: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x24]),
                    462: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x24]),
                    463: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x25]),
                    464: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x25]),
                    465: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x26]),
                    466: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x26]),
                    467: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x27]),
                    468: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x27]),
                    469: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x28]),
                    470: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x28]),
                    471: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x00, 0x29]),
                    472: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x29]),
                    473: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x30]),
                    474: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x30]),
                    475: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x31]),
                    476: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x31]),
                    477: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x32]),
                    478: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x32]),
                    479: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x00, 0x33]),
                    480: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x33]),
                    481: bytearray([0, 3, 1, 0, 4, 0, 0x1a, 0x05, 0x00, 0x34]),
                    482: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x34]),
                    483: bytearray([0, 3, 1, 0, 3, 0,  0x1a, 0x05, 0x00, 0x35]),
                    484: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x35]),
                    485: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x00, 0x36]),
                    486: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x36]),
                    487: bytearray([0, 3, 1, 0, 4, 0, 0x1a, 0x05, 0x00, 0x37]),
                    488: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x37]),
                    489: bytearray([0, 3, 1, 0, 5, 0, 0x1a, 0x05, 0x00, 0x38]),
                    490: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x38]),
                    491: bytearray([0, 3, 1, 0, 5, 0, 0x1a, 0x05, 0x00, 0x39]),
                    492: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x39]),
                    493: bytearray([0, 3, 1, 0, 5, 0, 0x1a, 0x05, 0x00, 0x41]),
                    494: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x41]),
                    495: bytearray([0, 3, 1, 0, 5, 0, 0x1a, 0x05, 0x00, 0x42]),
                    496: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x42]),
                    497: bytearray([0, 3, 1, 0, 5, 0, 0x1a, 0x05, 0x00, 0x43]),
                    498: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x43]),
                    499: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x44]),
                    500: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x44]),
                    501: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x45]),
                    502: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x45]),
                    503: bytearray([0, 4, 0, 0x1a, 0x05, 0x00, 0x46]),
                    504: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x46]),
                    505: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x47]),
                    506: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x47]),
                    507: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x48]),
                    508: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x48]),
                    509: bytearray([1, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x00, 0x49]),
                    510: bytearray([1, 2, 0, 0x1a, 0x05, 0x00, 0x49]),
                    511: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x00, 0x50]),
                    512: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x50]),
                    513: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x00, 0x51]),
                    514: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x51]),
                    515: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x52]),
                    516: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x52]),
                    517: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x53]),
                    518: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x53]),
                    519: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x54]),
                    520: bytearray([0, 2, 0,  0x1a, 0x05, 0x00, 0x54]),
                    521: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x55]),
                    522: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x55]),
                    523: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x00, 0x56]),
                    524: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x56]),
                    525: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x57]),
                    526: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x57]),
                    527: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x58]),
                    528: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x58]),
                    529: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x59]),
                    530: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x59]),
                    531: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x60]),
                    532: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x60]),
                    533: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x00, 0x61]),
                    534: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x61]),
                    535: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x62]),
                    536: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x62]),
                    537: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x63]),
                    538: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x63]),
                    539: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x64]),
                    540: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x64]),
                    541: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x00, 0x65]),
                    542: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x65]),
                    543: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x66]),
                    544: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x66]),
                    545: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x00, 0x67]),
                    546: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x67]),
                    547: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x00, 0x68]),
                    548: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x68]),
                    549: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x69]),
                    550: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x69]),
                    551: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x70]),
                    552: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x70]),
                    553: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x71]),
                    554: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x71]),
                    555: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x72]),
                    556: bytearray([0, 2,  0, 0x1a, 0x05, 0x00, 0x72]),
                    557: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x73]),
                    558: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x73]),
                    559: bytearray([0, 3, 1, 1, 30, 0, 0x1a, 0x05, 0x00, 0x74]),
                    560: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x74]),
                    561: bytearray([0, 3, 1, 1, 30, 0, 0x1a, 0x05, 0x00, 0x75]),
                    562: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x75]),
                    563: bytearray([0, 3, 1, 1, 30, 0, 0x1a, 0x05, 0x00, 0x76]),
                    564: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x76]),
                    565: bytearray([0, 3, 1, 1, 30, 0, 0x1a, 0x05, 0x00, 0x77]),
                    566: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x77]),
                    567: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x78]),
                    568: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x78]),
                    569: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x79]),
                    570: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x79]),
                    571: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x80]),
                    572: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x80]),
                    573: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x81]),
                    574: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x81]),
                    575: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x82]),
                    576: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x82]),
                    577: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x83]),
                    578: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x83]),
                    579: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x84]),
                    580: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x84]),
                    581: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x85]),
                    582: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x85]),
                    583: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x00, 0x86]),
                    584: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x86]),
                    585: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x87]),
                    586: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x87]),
                    587: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x88]),
                    588: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x88]),
                    589: bytearray([0, 4, 9, 2, 1, 255, 0x1a, 0x05, 0x00, 0x89]),
                    590: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x89]),
                    591: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x00, 0x90]),
                    592: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x90]),
                    593: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x00, 0x91]),
                    594: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x91]),
                    595: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x92]),
                    596: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x92]),
                    597: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x93]),
                    598: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x93]),
                    599: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x94]),
                    600: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x94]),
                    601: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x00, 0x95]),
                    602: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x95]),
                    603: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x00, 0x96]),
                    604: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x96]),
                    605: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x97]),
                    606: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x97]),
                    607: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x98]),
                    608: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x98]),
                    609: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x00, 0x99]),
                    610: bytearray([0, 2, 0, 0x1a, 0x05, 0x00, 0x99]),
                    611: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x00]),
                    612: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x00]),
                    613: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x01]),
                    614: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x01]),
                    615: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x01, 0x02]),
                    616: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x02]),
                    617: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x03]),
                    618: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x03]),
                    619: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x04]),
                    620: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x04]),
                    621: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x05]),
                    622: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x05]),
                    623: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x06]),
                    624: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x06]),
                    625: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x07]),
                    626: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x07]),
                    627: bytearray([0, 3, 1, 1, 30, 0, 0x1a, 0x05, 0x01, 0x08]),
                    628: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x08]),
                    629: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x09]),
                    630: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x09]),
                    631: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x01, 0x10]),
                    632: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x10]),
                    633: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x11]),
                    634: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x11]),
                    635: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x12]),
                    636: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x12]),
                    637: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x01, 0x13]),
                    638: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x13]),
                    639: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x14]),
                    640: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x14]),
                    641: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x15]),
                    642: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x15]),
                    643: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x01, 0x16]),
                    644: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x16]),
                    645: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x01, 0x17]),
                    646: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x17]),
                    647: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x01, 0x18]),
                    648: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x18]),
                    649: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x01, 0x19]),
                    650: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x19]),
                    651: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x20]),
                    652: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x20]),
                    653: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x21]),
                    654: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x21]),
                    655: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x23]),
                    656: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x23]),
                    657: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x24]),
                    658: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x24]),
                    659: bytearray([0, 3, 1, 0, 4, 0, 0x1a, 0x05, 0x01, 0x25]),
                    660: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x25]),
                    661: bytearray([0, 3, 1, 0, 4, 0, 0x1a, 0x05, 0x01, 0x26]),
                    662: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x26]),
                    663: bytearray([0, 3, 1, 0, 4, 0, 0x1a, 0x05, 0x01, 0x27]),
                    664: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x27]),
                    665: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x28]),
                    666: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x28]),
                    667: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x29]),
                    668: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x29]),
                    669: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x30]),
                    670: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x30]),
                    671: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x31]),
                    672: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x31]),
                    673: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x32]),
                    674: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x32]),
                    675: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x01, 0x33]),
                    676: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x33]),
                    677: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x34]),
                    678: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x34]),
                    679: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x35]),
                    680: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x35]),
                    681: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x01, 0x36]),
                    682: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x36]),
                    683: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x37]),
                    684: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x37]),
                    685: bytearray([0, 3, 1, 0, 6, 0, 0x1a, 0x05, 0x01, 0x38]),
                    686: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x38]),
                    687: bytearray([0, 3, 1, 0, 6, 0, 0x1a, 0x05, 0x01, 0x39]),
                    688: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x39]),
                    689: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x40]),
                    690: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x40]),
                    691: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x41]),
                    692: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x41]),
                    693: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x42]),
                    694: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x42]),
                    695: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x43]),
                    696: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x43]),
                    697: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x44]),
                    698: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x44]),
                    699: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x01, 0x45]),
                    700: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x45]),
                    701: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x46]),
                    702: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x46]),
                    703: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x47]),
                    704: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x47]),
                    705: bytearray([0, 3, 1, 0, 4, 0, 0x1a, 0x05, 0x01, 0x48]),
                    706: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x48]),
                    707: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x49]),
                    708: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x49]),
                    709: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x50]),
                    710: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x50]),
                    711: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x51]),
                    712: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x51]),
                    713: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x52]),
                    714: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x52]),
                    715: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x53]),
                    716: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x53]),
                    717: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x54]),
                    718: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x54]),
                    719: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x55]),
                    720: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x55]),
                    721: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x56]),
                    722: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x56]),
                    723: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x57]),
                    724: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x57]),
                    725: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x58]),
                    726: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x58]),
                    727: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x59]),
                    728: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x59]),
                    729: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x01, 0x60]),
                    730: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x60]),
                    731: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x61]),
                    732: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x61]),
                    733: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x01, 0x62]),
                    734: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x62]),
                    735: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x63]),
                    736: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x63]),
                    737: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x64]),
                    738: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x64]),
                    739: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x65]),
                    740: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x65]),
                    741: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x66]),
                    742: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x66]),
                    743: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x67]),
                    744: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x67]),
                    745: bytearray([0, 64, 11, 5, 0x1a, 0x05, 0x01, 0x68]),
                    746: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x68]),
                    747: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x69]),
                    748: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x69]),
                    749: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x70]),
                    750: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x70]),
                    751: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x71]),
                    752: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x71]),
                    753: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x72]),
                    754: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x72]),
                    755: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x73]),
                    756: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x73]),
                    757: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x74]),
                    758: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x74]),
                    759: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x75]),
                    760: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x75]),
                    761: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x76]),
                    762: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x76]),
                    763: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x77]),
                    764: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x77]),
                    765: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x01, 0x78]),
                    766: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x78]),
                    767: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x79]),
                    768: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x79]),
                    769: bytearray([0, 5, 3, 2, 255, 0, 255, 0, 255, 0, 0x1a, 0x05, 0x01, 0x80]),
                    770: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x80]),
                    771: bytearray([0, 5, 3, 2, 255, 0, 255, 0, 255, 0, 0x1a, 0x05, 0x01, 0x81]),
                    772: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x81]),
                    773: bytearray([0, 5, 3, 2, 255, 0, 255, 0, 255, 0, 0x1a, 0x05, 0x01, 0x82]),
                    774: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x82]),
                    775: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x83]),
                    776: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x83]),
                    777: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x84]),
                    778: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x84]),
                    779: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x01, 0x85]),
                    780: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x85]),
                    781: bytearray([0, 3, 1, 0, 7, 0, 0x1a, 0x05, 0x01, 0x86]),
                    782: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x86]),
                    783: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x01, 0x87]),
                    784: bytearray([0, 2, 0, 0x1a, 0x05, 0x01, 0x87]),
                    785: bytearray([0, 7, 0, 0x1a, 0x05, 0x01, 0x88]),
                    786: bytearray([0, 3, 0, 0x1a, 0x05, 0x01, 0x88]),
                    787: bytearray([0, 7, 0, 0x1a, 0x05, 0x01, 0x91]),
                    788: bytearray([0, 3, 0, 0x1a, 0x05, 0x01, 0x91]),
                    789: bytearray([0, 7, 0, 0x1a, 0x05, 0x01, 0x94]),
                    790: bytearray([0, 3, 0, 0x1a, 0x05, 0x01, 0x94]),
                    791: bytearray([0, 7, 0, 0x1a, 0x05, 0x01, 0x97]),
                    792: bytearray([0, 3, 0, 0x1a, 0x05, 0x01, 0x97]),
                    793: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x00]),
                    794: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x00]),
                    795: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x03]),
                    796: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x03]),
                    797: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x06]),
                    798: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x06]),
                    799: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x09]),
                    800: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x09]),
                    801: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x12]),
                    802: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x12]),
                    803: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x15]),
                    804: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x15]),
                    805: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x18]),
                    806: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x18]),
                    807: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x21]),
                    808: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x21]),
                    809: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x24]),
                    810: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x24]),
                    811: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x27]),
                    812: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x27]),
                    813: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x30]),
                    814: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x30]),
                    815: bytearray([0, 7, 0, 0x1a, 0x05, 0x02, 0x33]),
                    816: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x33]),
                    817: bytearray([0, 8, 0, 0x1a, 0x05, 0x02, 0x36]),
                    818: bytearray([0, 3, 0, 0x1a, 0x05, 0x02, 0x36]),
                    819: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x39]),
                    820: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x39]),
                    821: bytearray([0, 5, 3, 2, 255, 0, 255, 0, 255, 0, 0x1a, 0x05, 0x02, 0x40]),
                    822: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x40]),
                    823: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x41]),
                    824: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x41]),
                    825: bytearray([0, 5, 3, 2, 255, 0, 255, 0, 255, 0, 0x1a, 0x05, 0x02, 0x42]),
                    826: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x42]),
                    827: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x02, 0x43]),
                    828: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x43]),
                    829: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x44]),
                    830: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x44]),
                    831: bytearray([0, 3, 1, 1, 14, 1, 0x1a, 0x05, 0x02, 0x45]),
                    832: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x45]),
                    833: bytearray([0, 3, 1, 0, 4, 0, 0x1a, 0x05, 0x02, 0x46]),
                    834: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x46]),
                    835: bytearray([0, 3, 1, 0, 7, 1, 0x1a, 0x05, 0x02, 0x47]),
                    836: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x47]),
                    837: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x48]),
                    838: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x48]),
                    839: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x02, 0x49]),
                    840: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x49]),
                    841: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x50]),
                    842: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x50]),
                    843: bytearray([0, 3, 1, 1, 59, 1, 0x1a, 0x05, 0x02, 0x51]),
                    844: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x51]),
                    845: bytearray([0, 3, 1, 1, 17, 28, 0x1a, 0x05, 0x02, 0x52]),
                    846: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x52]),
                    847: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x02, 0x53]),
                    848: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x53]),
                    849: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x54]),
                    850: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x54]),
                    851: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x02, 0x55]),
                    852: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x55]),
                    853: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x02, 0x56]),
                    854: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x56]),
                    855: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x02, 0x57]),
                    856: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x57]),
                    857: bytearray([0, 5, 3, 2, 255, 0, 255, 0, 255, 0, 0x1a, 0x05, 0x02, 0x58]),
                    858: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x58]),
                    859: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x59]),
                    860: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x59]),
                    861: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x60]),
                    862: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x60]),
                    863: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x61]),
                    864: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x61]),
                    865: bytearray([0, 5, 3, 2, 255, 0, 255, 0, 255, 0, 0x1a, 0x05, 0x02, 0x62]),
                    866: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x62]),
                    867: bytearray([0, 5, 3, 2, 255, 0, 255, 0, 255, 0, 0x1a, 0x05, 0x02, 0x63]),
                    868: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x63]),
                    869: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x64]),
                    870: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x64]),
                    871: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x65]),
                    872: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x65]),
                    873: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x66]),
                    874: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x66]),
                    875: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x67]),
                    876: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x67]),
                    877: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x68]),
                    878: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x68]),
                    879: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x69]),
                    880: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x69]),
                    881: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x70]),
                    882: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x70]),
                    883: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x71]),
                    884: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x71]),
                    885: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x72]),
                    886: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x72]),
                    887: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x02, 0x73]),
                    888: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x73]),
                    889: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x02, 0x74]),
                    890: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x74]),
                    891: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x75]),
                    892: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x75]),
                    893: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x76]),
                    894: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x76]),
                    895: bytearray([0, 3, 1, 1, 10, 0, 0x1a, 0x05, 0x02, 0x77]),
                    896: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x77]),
                    897: bytearray([0, 3, 1, 0, 6, 0, 0x1a, 0x05, 0x02, 0x78]),
                    898: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x78]),
                    899: bytearray([0, 3, 1, 0, 4, 0, 0x1a, 0x05, 0x02, 0x79]),
                    900: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x79]),
                    901: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x80]),
                    902: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x80]),
                    903: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x02, 0x81]),
                    904: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x81]),
                    905: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x82]),
                    906: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x82]),
                    907: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x83]),
                    908: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x83]),
                    909: bytearray([0, 3, 1, 0, 5, 0, 0x1a, 0x05, 0x02, 0x84]),
                    910: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x84]),
                    911: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x02, 0x85]),
                    912: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x85]),
                    913: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x86]),
                    914: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x86]),
                    915: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x02, 0x87]),
                    916: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x87]),
                    917: bytearray([0, 56, 11, 0, 0x1a, 0x05, 0x02, 0x88]),
                    918: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x88]),
                    919: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x02, 0x89]),
                    920: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x89]),
                    921: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x02, 0x90]),
                    922: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x90]),
                    923: bytearray([0, 5, 0, 0x1a, 0x05, 0x02, 0x91]),
                    924: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x91]),
                    925: bytearray([0, 3, 1, 1, 42, 0, 0x1a, 0x05, 0x02, 0x95]),
                    926: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x95]),
                    927: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x02, 0x96]),
                    928: bytearray([0, 2, 0, 0x1a, 0x05, 0x02, 0x96]),
                    929: bytearray([0, 4, 2, 0, 3, 0, 43, 0, 0x1a, 0x05, 0x02, 0x97]),
                    930: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x02, 0x97]),
                    931: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x03, 0x01]),
                    932: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x01]),
                    933: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x02]),
                    934: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x02]),
                    935: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x03, 0x03]),
                    936: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x03]),
                    937: bytearray([0, 3, 1, 0, 9, 0, 0x1a, 0x05, 0x03, 0x04]),
                    938: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x04]),
                    939: bytearray([0, 3, 1, 0, 9, 0, 0x1a, 0x05, 0x03, 0x05]),
                    940: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x05]),
                    941: bytearray([0, 3, 1, 0, 9, 0, 0x1a, 0x05, 0x03, 0x06]),
                    942: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x06]),
                    943: bytearray([0, 3, 1, 0, 8, 0, 0x1a, 0x05, 0x03, 0x07]),
                    944: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x07]),
                    945: bytearray([0, 9, 11, 0, 0x1a, 0x05, 0x03, 0x08]),
                    946: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x08]),
                    947: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x09]),
                    948: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x09]),
                    949: bytearray([0, 4, 2,  255, 38, 0, 9, 0,  0x1a, 0x05, 0x03, 0x10]),
                    950: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x10]),
                    951: bytearray([0, 3, 1, 255, 43, 0,  0x1a, 0x05, 0x03, 0x11]),
                    952: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x11]),
                    953: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x12]),
                    954: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x12]),
                    955: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x03, 0x13]),
                    956: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x13]),
                    957: bytearray([0, 4, 1, 0, 1, 104, 0x1a, 0x05, 0x03, 0x014]),
                    958: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x14]),
                    959: bytearray([0, 4, 1, 0, 7, 58, 0x1a, 0x05, 0x03, 0x15]),
                    960: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x15]),
                    961: bytearray([0, 3, 1, 0, 9, 0, 0x1a, 0x05, 0x03, 0x16]),
                    962: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x16]),
                    963: bytearray([0, 3, 1, 0, 9, 0, 0x1a, 0x05, 0x03, 0x17]),
                    964: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x17]),
                    965: bytearray([0, 3, 1, 0, 9, 0,  0x1a, 0x05, 0x03, 0x18]),
                    966: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x18]),
                    967: bytearray([0, 3, 1, 0, 8, 0, 0x1a, 0x05, 0x03, 0x19]),
                    968: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x19]),
                    969: bytearray([00, 3, 1, 1, 42, 0, 0x1a, 0x05, 0x03, 0x20]),
                    970: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x20]),
                    971: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x21]),
                    972: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x21]),
                    973: bytearray([0, 9, 11, 0, 0x1a, 0x05, 0x03, 0x22]),
                    974: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x22]),
                    975: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x23]),
                    976: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x23]),
                    977: bytearray([0, 4, 2,  255, 38, 0, 94, 0,  0x1a, 0x05, 0x03, 0x24]),
                    978: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x24]),
                    979: bytearray([0, 4, 1, 255, 43, 0,  0x1a, 0x05, 0x03, 0x25]),
                    980: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x25]),
                    981: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x26]),
                    982: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x26]),
                    983: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x03, 0x27]),
                    984: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x27]),
                    985: bytearray([0, 4, 1, 0, 1, 104, 0x1a, 0x05, 0x03, 0x028]),
                    986: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x28]),
                    987: bytearray([0, 4, 1, 0, 7, 58, 0x1a, 0x05, 0x03, 0x29]),
                    988: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x29]),
                    989: bytearray([0, 3, 1, 0, 9, 0, 0x1a, 0x05, 0x03, 0x30]),
                    990: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x30]),
                    991: bytearray([0, 3, 1, 0, 9, 0, 0x1a, 0x05, 0x03, 0x31]),
                    992: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x31]),
                    993: bytearray([0, 3, 1, 0, 9, 0,  0x1a, 0x05, 0x03, 0x32]),
                    994: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x32]),
                    995: bytearray([0, 3, 1, 0, 8, 0, 0x1a, 0x05, 0x03, 0x33]),
                    996: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x33]),
                    997: bytearray([0, 3, 1, 1, 42, 0, 0x1a, 0x05, 0x03, 0x34]),
                    998: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x34]),
                    999: bytearray([0, 4, 2, 255, 38, 0, 94, 0, 0x1a, 0x05, 0x03, 0x35]),
                    1000: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x35]),
                    1001: bytearray([0, 3, 1, 1, 42, 0, 0x1a, 0x05, 0x03, 0x36]),
                    1002: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x36]),
                    1003: bytearray([0, 4, 1, 255, 43, 0, 0x1a, 0x05, 0x03, 0x37]),
                    1004: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x37]),
                    1005: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x03, 0x38]),
                    1006: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x38]),
                    1007: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x39]),
                    1008: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x39]),
                    1009: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x40]),
                    1010: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x40]),
                    1011: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x41]),
                    1012: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x41]),
                    1013: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x42]),
                    1014: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x42]),
                    1015: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x43]),
                    1016: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x43]),
                    1017: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x44]),
                    1018: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x44]),
                    1019: bytearray([0, 20, 11, 0, 0x1a, 0x05, 0x03, 0x45]),
                    1020: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x45]),
                    1021: bytearray([0, 4, 0, 0x1a, 0x05, 0x03, 0x46]),
                    1022: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x46]),
                    1023: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x03, 0x47]),
                    1024: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x47]),
                    1025: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x48]),
                    1026: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x48]),
                    1027: bytearray([0, 3, 1, 0, 6, 0, 0x1a, 0x05, 0x03, 0x49]),
                    1028: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x49]),
                    1029: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x50]),
                    1030: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x50]),
                    1031: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x51]),
                    1032: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x51]),
                    1033: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x52]),
                    1034: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x52]),
                    1035: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x53]),
                    1036: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x53]),
                    1037: bytearray([0, 3, 1, 0, 6, 0, 0x1a, 0x05, 0x03, 0x54]),
                    1038: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x54]),
                    1039: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x03, 0x55]),
                    1040: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x55]),
                    1041: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x03, 0x56]),
                    1042: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x56]),
                    1043: bytearray([0, 3, 1, 0, 9, 0, 0x1a, 0x05, 0x03, 0x57]),
                    1044: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x57]),
                    1045: bytearray([0, 3, 1, 2, 255, 0, 0x1a, 0x05, 0x03, 0x58]),
                    1046: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x58]),
                    1047: bytearray([0, 3, 1, 1, 20, 0, 0x1a, 0x05, 0x03, 0x59]),
                    1048: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x59]),
                    1049: bytearray([0, 3, 1, 0, 3, 0, 0x1a, 0x05, 0x03, 0x60]),
                    1050: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x60]),
                    1051: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x61]),
                    1052: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x61]),
                    1053: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x05, 0x03, 0x62]),
                    1054: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x62]),
                    1055: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x63]),
                    1056: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x63]),
                    1057: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x64]),
                    1058: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x64]),
                    1059: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x65]),
                    1060: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x65]),
                    1061: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x05, 0x03, 0x66]),
                    1062: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x66]),
                    1063: bytearray([0, 3, 1, 1, 17, 0, 0x1a, 0x05, 0x03, 0x67]),
                    1064: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x67]),
                    1065: bytearray([0, 3, 1, 1, 4, 0, 0x1a, 0x05, 0x03, 0x68]),
                    1066: bytearray([0, 2, 0, 0x1a, 0x05, 0x03, 0x68]),
                    1067: bytearray([0, 3, 2, 0, 1, 0, 2, 1,0x1a, 0x06]),
                    1068: bytearray([0, 2, 0, 0x1a, 0x06]),
                    1069: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x07]),
                    1070: bytearray([0, 2, 0, 0x1a, 0x07]),
                    1071: bytearray([0, 2, 0, 0x1a, 0x08]),
                    1072: bytearray([0, 2, 0, 0x1a, 0x09]),
                    1073: bytearray([0, 3, 1, 0, 2, 0, 0x1a, 0x0a]),
                    1074: bytearray([0, 2, 0, 0x1a, 0x0a]),
                    1075: bytearray([0, 2, 0, 0x1a, 0x0b]),
                    1076: bytearray([0, 3, 0, 0x1b, 0x00]),
                    1077: bytearray([0, 2, 0, 0x1b, 0x00]),
                    1078: bytearray([0, 3, 0, 0x1b, 0x01]),
                    1079: bytearray([0, 2, 0, 0x1b, 0x01]),
                    1080: bytearray([0, 3, 0, 0x1b, 0x02]),
                    1081: bytearray([0, 2, 0, 0x1b, 0x02]),
                    1082: bytearray([0, 3, 1, 1, 99, 0, 0x1b, 0x07]),
                    1083: bytearray([0, 2, 0, 0x1b, 0x07]),
                    1084: bytearray([0, 3, 1, 0, 1, 0, 0x1c, 0x00]),
                    1085: bytearray([0, 2, 0, 0x1c, 0x00]),
                    1086: bytearray([0, 3, 1, 0, 2, 0, 0x1c, 0x01]),
                    1087: bytearray([0, 2, 0, 0x1c, 0x01]),
                    1088: bytearray([0, 3, 1, 0, 1, 0, 0x1c, 0x02]),
                    1089: bytearray([0, 2, 0, 0x1c, 0x02]),
                    1090: bytearray([0, 2, 0, 0x1c, 0x03]),
                    1091: bytearray([0, 2, 0, 0x1e, 0x00]),
                    1092: bytearray([0, 3, 1, 1, 11, 1, 0x1e, 0x01]),
                    1093: bytearray([0, 2, 0, 0x1e, 0x02]),
                    1094: bytearray([0, 12, 0, 0x1e, 0x03]),
                    1095: bytearray([0, 3, 1, 1, 29, 1, 0x1e, 0x03]),
                    1096: bytearray([0, 13, 11, 4, 0x1f, 0x00]),
                    1097: bytearray([0, 2, 0, 0x1f, 0x00]),
                    1098: bytearray([0, 24, 11, 4, 0x1f, 0x01]),
                    1099: bytearray([0, 2, 0, 0x1f, 0x01]),
                    1100: bytearray([0, 20, 11, 0, 0x1f, 0x02]),
                    1101: bytearray([0, 2, 0, 0x1f, 0x02]),
                    1102: bytearray([0, 3, 1, 0, 1, 0, 0x20, 0x00, 0x00]),
                    1103: bytearray([0, 2, 0, 0x20, 0x00, 0x00]),
                    1104: bytearray([0, 2, 0, 0x20, 0x00, 0x01]),
                    1105: bytearray([0, 2, 0, 0x20, 0x00, 0x01]),
                    1106: bytearray([0, 2, 0, 0x20, 0x00, 0x02]),
                    1107: bytearray([0, 3, 1, 0, 1, 0, 0x20, 0x01, 0x00]),
                    1108: bytearray([0, 2, 0, 0x20, 0x01, 0x00]),
                    1109: bytearray([0, 2, 0, 0x20, 0x01, 0x01]),
                    1110: bytearray([0, 2, 0, 0x20, 0x01, 0x01]),
                    1111: bytearray([0, 2, 0, 0x20, 0x01, 0x02]),
                    1112: bytearray([0, 3, 1, 0, 1, 0, 0x20, 0x02, 0x00]),
                    1113: bytearray([0, 2, 0, 0x20, 0x02, 0x00]),
                    1114: bytearray([0, 3, 1, 0, 127, 0, 0x20, 0x02, 0x01]),
                    1115: bytearray([0, 2, 0, 0x20, 0x02, 0x01]),
                    1116: bytearray([0, 2, 0, 0x20, 0x02, 0x02]),
                    1117: bytearray([0, 3, 1, 0, 1, 0, 0x20, 0x03, 0x00]),
                    1118: bytearray([0, 2, 0, 0x20, 0x03, 0x00]),
                    1119: bytearray([0, 2, 1, 0, 1, 0, 0x20, 0x03, 0x01, 0x00]),
                    1120: bytearray([0, 2, 1, 0, 1, 0, 0x20, 0x03, 0x01, 0x01]),
                    1121: bytearray([0, 2, 1, 0, 1, 0, 0x20, 0x03, 0x01, 0x02]),
                    1122: bytearray([0, 2, 1, 0, 1, 0, 0x20, 0x03, 0x01, 0x03]),
                    1123: bytearray([0, 2, 1, 0, 1, 0, 0x20, 0x03, 0x02, 0x00]),
                    1124: bytearray([0, 2, 1, 0, 1, 0, 0x20, 0x03, 0x02, 0x01]),
                    1125: bytearray([0, 2, 1, 0, 1, 0, 0x20, 0x03, 0x02, 0x02]),
                    1126: bytearray([0, 2, 1, 0, 1, 0, 0x20, 0x03, 0x02, 0x03]),
                    1127: bytearray([0, 3, 1, 0, 1, 0, 0x20, 0x04, 0x00]),
                    1128: bytearray([0, 2, 0, 0x20, 0x04, 0x00]),
                    1129: bytearray([0, 2, 0, 0x20, 0x04, 0x01]),
                    1130: bytearray([0, 2, 0, 0x20, 0x04, 0x01]),
                    1131: bytearray([0, 2, 0, 0x20, 0x04, 0x02]),
                    1132: bytearray([0, 2, 0, 0x21, 0x00]),
                    1133: bytearray([0, 2, 0, 0x21, 0x00]),
                    1134: bytearray([0, 3, 1, 0, 1, 0, 0x21, 0x01]),
                    1135: bytearray([0, 2, 0, 0x21, 0x01]),
                    1136: bytearray([0, 3, 1, 0, 1, 0, 0x21, 0x02]),
                    1137: bytearray([0, 2, 0, 0x21, 0x02]),
                    1138: bytearray([0, 30, 11, 0x00, 0x22, 0x00]),
                    1139: bytearray([0, 2, 0, 0x22, 0x00]),
                    1140: bytearray([0, 3, 1, 0, 1, 0, 0x22, 0x01, 0x00]),
                    1141: bytearray([0, 2, 0, 0x22, 0x01, 0x00]),
                    1142: bytearray([0, 2, 0, 0x22, 0x01, 0x01]),
                    1143: bytearray([0, 3, 1, 0, 1, 0, 0x22, 0x02]),
                    1144: bytearray([0, 2, 0, 0x22, 0x02]),
                    1145: bytearray([0, 3, 1, 0, 1, 0, 0x22, 0x03]),
                    1146: bytearray([0, 2, 0, 0x22, 0x03]),
                    1147: bytearray([0, 3, 1, 0, 1, 0, 0x22, 0x04]),
                    1148: bytearray([0, 2, 0, 0x22, 0x04]),
                    1149: bytearray([0, 3, 1, 1, 10, 0, 0x22, 0x05]),
                    1150: bytearray([0, 2, 0, 0x22, 0x05]),
                    1151: bytearray([0, 2, 0, 0x23, 0x00]),
                    1152: bytearray([0, 2, 0, 0x23, 0x01]),
                    1153: bytearray([0, 2, 0, 0x23, 0x01]),
                    1154: bytearray([0, 2, 0, 0x23, 0x02]),
                    1155: bytearray([0, 2, 0, 0x23, 0x02]),
                    1156: bytearray([0, 3, 1, 0, 1, 0, 0x24, 0x00, 0x00]),
                    1157: bytearray([0, 2, 0, 0x24, 0x00, 0x00]),
                    1158: bytearray([0, 2, 0, 0x24, 0x00, 0x01]),
                    1159: bytearray([0, 2, 0, 0x25]),
                    1160: bytearray([0, 3, 1, 0, 1, 0, 0x25]),
                    1161: bytearray([0, 2, 0, 0x26]),
                    1162: bytearray([0, 3, 1, 0, 1, 0, 0x26]),
                    1163: bytearray([0, 2, 0, 0x27, 0x00]),
                    1164: bytearray([0, 3, 1, 0, 1, 0, 0x27, 0x10]),
                    1165: bytearray([0, 2, 0, 0x27, 0x10]),
                    1166: bytearray([0, 3, 1, 0, 1, 0, 0x27, 0x11]),
                    1167: bytearray([0, 2, 0, 0x27, 0x11]),
                    1168: bytearray([0, 2, 0, 0x27, 0x12]),
                    1169: bytearray([0, 2, 0, 0x27, 0x13]),
                    1170: bytearray([0, 3, 1, 0, 3, 0, 0x27, 0x14, 0x00]),
                    1171: bytearray([0, 2, 0, 0x27, 0x14, 0x00]),
                    1172: bytearray([0, 3, 1, 0, 7, 0, 0x27, 0x15, 0x00]),
                    1173: bytearray([0, 2, 0, 0x27, 0x15, 0x00]),
                    1174: bytearray([0, 3, 1, 0, 3, 1, 0x27, 0x16, 0x00]),
                    1175: bytearray([0, 2, 0, 0x27, 0x16, 0x00]),
                    1176: bytearray([0, 3, 1, 0, 1, 0, 0x27, 0x17, 0x00]),
                    1177: bytearray([0, 2, 0, 0x27, 0x17, 0x00]),
                    1178: bytearray([0, 2, 0, 0x27, 0x19, 0x00]),
                    1179: bytearray([0, 2, 0, 0x27, 0x19, 0x00]),
                    1180: bytearray([0, 3, 1, 0, 2, 0, 0x27, 0x1a, 0x00]),
                    1181: bytearray([0, 2, 0, 0x27, 0x1a, 0x00]),
                    1182: bytearray([0, 3, 1, 0, 1, 0, 0x27, 0x1b]),
                    1183: bytearray([0, 2, 0, 0x27, 0x1b]),
                    1184: bytearray([0, 3, 1, 0, 2, 0, 0x27, 0x1c]),
                    1185: bytearray([0, 2, 0, 0x27, 0x1c]),
                    1186: bytearray([0, 3, 1, 0, 1, 0, 0x27, 0x1d, 0x00]),
                    1187: bytearray([0, 2, 0, 0x27, 0x1d, 0x00]),
                    1188: bytearray([0, 3, 1, 0, 1, 0, 0x27, 0x20]),
                    1189: bytearray([0, 2, 0, 0x27, 0x20]),
                    1190: bytearray([0, 3, 1, 0, 8, 0, 0x28, 0x00]),
                    1191: bytearray([0, 3, 1, 1, 13, 0, 0x1a, 0x04]),
                    1192: bytearray([0, 2, 0, 0x1a, 0x04]),
                    1193: bytearray([0, 3, 1, 1, 13, 0, 0x1a, 0x04]),
                    1194: bytearray([0, 2, 0, 0x1a, 0x04]),
                    1195: bytearray([0,1,0,0,0,0,0]),
                    1196: bytearray([0, 3, 1, 0, 1, 0, 0x1a, 0x0c]),
                    1197: bytearray([0, 2, 0, 0x1a, 0x0c]),
                    }


civ_code_to_token =    {"00": 257,
                        "01": 259,
                        "02": 260,
                        "03": 257,
                        "04": 259,
                        "0c": 266,
                        "0f": 275,
                        "10": 277,
                        "11": 279,
                        "1401": 282,
                        "1402": 284,
                        "1403": 286,
                        "1406": 288,
                        "1407": 290,
                        "1408": 292,
                        "1409": 294,
                        "140a": 296,
                        "140b": 298,
                        "140c": 300,
                        "140d": 302,
                        "140e": 304,
                        "140f": 306,
                        "1412": 308,
                        "1415": 310,
                        "1416": 312,
                        "1417": 314,
                        "1419": 316,
                        "1501": 317,
                        "1502": 318,
                        "1505": 319,
                        "1511": 320,
                        "1512": 321,
                        "1513": 322,
                        "1514": 323,
                        "1515": 324,
                        "1516": 325,
                        "1602": 327,
                        "1612": 329,
                        "1622": 331,
                        "1640": 333,
                        "1641": 335,
                        "1642": 337,
                        "1643": 339,
                        "1644": 341,
                        "1645": 343,
                        "1646": 345,
                        "1647": 347,
                        "1648": 349,
                        "164b": 351,
                        "164f": 353,
                        "1650": 355,
                        "1656": 357,
                        "1657": 359,
                        "1658": 361,
                        "165b": 363,
                        "165c": 365,
                        "165d": 367,
                        "1900": 370,
                        "1a00": 372,
                        "1a01": 403,
                        "1a02": 406,
                        "1a03": 408,
                        "1a04": 1191,
                        "1a050001": 416,
                        "1a050002": 418,
                        "1a050003": 420,
                        "1a050004": 422,
                        "1a050005": 424,
                        "1a050006": 426,
                        "1a050007": 428,
                        "1a050008": 430,
                        "1a050009": 432,
                        "1a050010": 434,
                        "1a050011": 436,
                        "1a050012": 438,
                        "1a050013": 440,
                        "1a050014": 442,
                        "1a050015": 444,
                        "1a050016": 446,
                        "1a050017": 448,
                        "1a050018": 450,
                        "1a050019": 452,
                        "1a050020": 454,
                        "1a050021": 456,
                        "1a050022": 458,
                        "1a050023": 460,
                        "1a050024": 462,
                        "1a050025": 464,
                        "1a050026": 466,
                        "1a050027": 468,
                        "1a050028": 470,
                        "1a050029": 472,
                        "1a050030": 474,
                        "1a050031": 476,
                        "1a050032": 478,
                        "1a050033": 480,
                        "1a050034": 482,
                        "1a050035": 484,
                        "1a050036": 486,
                        "1a050037": 488,
                        "1a050038": 490,
                        "1a050039": 492,
                        "1a050041": 494,
                        "1a050042": 496,
                        "1a050043": 498,
                        "1a050044": 500,
                        "1a050045": 502,
                        "1a050046": 504,
                        "1a050047": 506,
                        "1a050048": 508,
                        "1a050049": 510,
                        "1a050050": 512,
                        "1a050051": 514,
                        "1a050052": 516,
                        "1a050053": 518,
                        "1a050054": 520,
                        "1a050055": 522,
                        "1a050056": 524,
                        "1a050057": 526,
                        "1a050058": 528,
                        "1a050059": 530,
                        "1a050060": 532,
                        "1a050061": 534,
                        "1a050062": 536,
                        "1a050063": 538,
                        "1a050064": 540,
                        "1a050065": 542,
                        "1a050066": 544,
                        "1a050067": 546,
                        "1a050068": 548,
                        "1a050069": 550,
                        "1a050070": 552,
                        "1a050071": 554,
                        "1a050072": 556,
                        "1a050073": 558,
                        "1a050074": 560,
                        "1a050075": 562,
                        "1a050076": 564,
                        "1a050077": 566,
                        "1a050078": 568,
                        "1a050079": 570,
                        "1a050080": 572,
                        "1a050081": 574,
                        "1a050082": 576,
                        "1a050083": 578,
                        "1a050084": 580,
                        "1a050085": 582,
                        "1a050086": 584,
                        "1a050087": 586,
                        "1a050088": 588,
                        "1a050089": 590,
                        "1a050090": 592,
                        "1a050091": 594,
                        "1a050092": 596,
                        "1a050093": 598,
                        "1a050094": 600,
                        "1a050095": 602,
                        "1a050096": 604,
                        "1a050097": 606,
                        "1a050098": 608,
                        "1a050099": 610,
                        "1a050100": 612,
                        "1a050101": 614,
                        "1a050102": 616,
                        "1a050103": 618,
                        "1a050104": 620,
                        "1a050105": 622,
                        "1a050106": 624,
                        "1a050107": 626,
                        "1a050108": 628,
                        "1a050109": 630,
                        "1a050110": 632,
                        "1a050111": 634,
                        "1a050112": 636,
                        "1a050113": 638,
                        "1a050114": 640,
                        "1a050115": 642,
                        "1a050116": 644,
                        "1a050117": 646,
                        "1a050118": 648,
                        "1a050119": 650,
                        "1a050120": 652,
                        "1a050121": 654,
                        "1a050123": 656,
                        "1a050124": 658,
                        "1a050125": 660,
                        "1a050126": 662,
                        "1a050127": 664,
                        "1a050128": 666,
                        "1a050129": 668,
                        "1a050130": 670,
                        "1a050131": 672,
                        "1a050132": 674,
                        "1a050133": 676,
                        "1a050134": 678,
                        "1a050135": 680,
                        "1a050136": 682,
                        "1a050137": 684,
                        "1a050138": 686,
                        "1a050139": 688,
                        "1a050140": 690,
                        "1a050141": 692,
                        "1a050142": 694,
                        "1a050143": 696,
                        "1a050144": 698,
                        "1a050145": 700,
                        "1a050146": 702,
                        "1a050147": 704,
                        "1a050148": 706,
                        "1a050149": 708,
                        "1a050150": 710,
                        "1a050151": 712,
                        "1a050152": 714,
                        "1a050153": 716,
                        "1a050154": 718,
                        "1a050155": 720,
                        "1a050156": 722,
                        "1a050157": 724,
                        "1a050158": 726,
                        "1a050159": 728,
                        "1a050160": 730,
                        "1a050161": 732,
                        "1a050162": 734,
                        "1a050163": 736,
                        "1a050164": 738,
                        "1a050165": 740,
                        "1a050166": 742,
                        "1a050167": 744,
                        "1a050168": 746,
                        "1a050169": 748,
                        "1a050170": 750,
                        "1a050171": 752,
                        "1a050172": 754,
                        "1a050173": 756,
                        "1a050174": 758,
                        "1a050175": 760,
                        "1a050176": 762,
                        "1a050177": 764,
                        "1a050178": 766,
                        "1a050179": 768,
                        "1a050180": 770,
                        "1a050181": 772,
                        "1a050182": 774,
                        "1a050183": 776,
                        "1a050184": 778,
                        "1a050185": 780,
                        "1a050186": 782,
                        "1a050187": 784,
                        "1a050188": 786,
                        "1a050189": 786,
                        "1a050190": 786,
                        "1a050191": 788,
                        "1a050192": 788,
                        "1a050193": 788,
                        "1a050194": 790,
                        "1a050195": 790,
                        "1a050196": 790,
                        "1a050197": 792,
                        "1a050198": 792,
                        "1a050199": 792,
                        "1a050200": 794,
                        "1a050201": 794,
                        "1a050202": 794,
                        "1a050203": 796,
                        "1a050204": 796,
                        "1a050205": 796,
                        "1a050206": 798,
                        "1a050207": 798,
                        "1a050208": 798,
                        "1a050209": 800,
                        "1a050210": 800,
                        "1a050211": 800,
                        "1a050212": 802,
                        "1a050213": 802,
                        "1a050214": 802,
                        "1a050215": 804,
                        "1a050216": 804,
                        "1a050217": 804,
                        "1a050218": 806,
                        "1a050219": 806,
                        "1a050220": 806,
                        "1a050221": 808,
                        "1a050222": 808,
                        "1a050223": 808,
                        "1a050224": 810,
                        "1a050225": 810,
                        "1a050226": 810,
                        "1a050227": 812,
                        "1a050228": 812,
                        "1a050229": 812,
                        "1a050230": 814,
                        "1a050231": 814,
                        "1a050232": 814,
                        "1a050233": 816,
                        "1a050234": 816,
                        "1a050235": 816,
                        "1a050236": 818,
                        "1a050237": 818,
                        "1a050238": 818,
                        "1a050239": 820,
                        "1a050240": 822,
                        "1a050241": 824,
                        "1a050242": 826,
                        "1a050243": 828,
                        "1a050244": 830,
                        "1a050245": 832,
                        "1a050246": 834,
                        "1a050247": 836,
                        "1a050248": 838,
                        "1a050249": 840,
                        "1a050250": 842,
                        "1a050251": 844,
                        "1a050252": 846,
                        "1a050253": 848,
                        "1a050254": 850,
                        "1a050255": 852,
                        "1a050256": 854,
                        "1a050257": 856,
                        "1a050258": 858,
                        "1a050259": 860,
                        "1a050260": 862,
                        "1a050261": 864,
                        "1a050262": 866,
                        "1a050263": 868,
                        "1a050264": 870,
                        "1a050265": 872,
                        "1a050266": 874,
                        "1a050267": 876,
                        "1a050268": 878,
                        "1a050269": 880,
                        "1a050270": 882,
                        "1a050271": 884,
                        "1a050272": 886,
                        "1a050273": 888,
                        "1a050274": 890,
                        "1a050275": 892,
                        "1a050276": 894,
                        "1a050277": 896,
                        "1a050278": 898,
                        "1a050279": 900,
                        "1a050280": 902,
                        "1a050281": 904,
                        "1a050282": 906,
                        "1a050283": 908,
                        "1a050284": 910,
                        "1a050285": 912,
                        "1a050286": 914,
                        "1a050287": 916,
                        "1a050288": 918,
                        "1a050289": 920,
                        "1a050290": 922,
                        "1a050291": 924,
                        "1a050292": 924,
                        "1a050293": 924,
                        "1a050294": 924,
                        "1a050295": 926,
                        "1a050296": 928,
                        "1a050297": 930,
                        "1a050298": 930,
                        "1a050299": 930,
                        "1a050300": 930,
                        "1a050301": 932,
                        "1a050302": 934,
                        "1a050303": 936,
                        "1a050304": 938,
                        "1a050305": 940,
                        "1a050306": 942,
                        "1a050307": 944,
                        "1a050308": 946,
                        "1a050309": 948,
                        "1a050310": 950,
                        "1a050311": 952,
                        "1a050312": 954,
                        "1a050313": 956,
                        "1a050314": 958,
                        "1a050315": 960,
                        "1a050316": 962,
                        "1a050317": 964,
                        "1a050318": 966,
                        "1a050319": 968,
                        "1a050320": 970,
                        "1a050321": 972,
                        "1a050322": 974,
                        "1a050323": 976,
                        "1a050324": 978,
                        "1a050325": 980,
                        "1a050326": 982,
                        "1a050327": 984,
                        "1a050328": 986,
                        "1a050329": 988,
                        "1a050330": 990,
                        "1a050331": 992,
                        "1a050332": 994,
                        "1a050333": 996,
                        "1a050334": 998,
                        "1a050335": 1000,
                        "1a050336": 1002,
                        "1a050337": 1004,
                        "1a050338": 1006,
                        "1a050339": 1008,
                        "1a050340": 1010,
                        "1a050341": 1012,
                        "1a050342": 1014,
                        "1a050343": 1016,
                        "1a050344": 1018,
                        "1a050345": 1020,
                        "1a050346": 1022,
                        "1a050347": 1024,
                        "1a050348": 1026,
                        "1a050349": 1028,
                        "1a050350": 1030,
                        "1a050351": 1032,
                        "1a050352": 1034,
                        "1a050353": 1036,
                        "1a050354": 1038,
                        "1a050355": 1040,
                        "1a050356": 1042,
                        "1a050357": 1044,
                        "1a050358": 1046,
                        "1a050359": 1048,
                        "1a050360": 1050,
                        "1a050361": 1052,
                        "1a050362": 1054,
                        "1a050363": 1056,
                        "1a050364": 1058,
                        "1a050365": 1060,
                        "1a050366": 1062,
                        "1a050367": 1064,
                        "1a050368": 1066,
                        "1a050369": 786,
                        "1a050370": 788,
                        "1a050371": 790,
                        "1a050372": 792,
                        "1a050373": 794,
                        "1a050374": 796,
                        "1a050375": 798,
                        "1a050376": 800,
                        "1a050377": 802,
                        "1a050378": 804,
                        "1a050379": 806,
                        "1a050380": 808,
                        "1a050381": 810,
                        "1a050382": 812,
                        "1a050383": 814,
                        "1a050384": 816,
                        "1a050385": 818,
                        "1a06": 1068,
                        "1a07": 1070,
                        "1a08": 1071,
                        "1a09": 1072,
                        "1a0a": 1074,
                        "1a0b": 1075,
                        "1b00": 1077,
                        "1b01": 1079,
                        "1b02": 1081,
                        "1b07": 1083,
                        "1c00": 1085,
                        "1c01": 1087,
                        "1c02": 1089,
                        "1c03": 1090,
                        "1e00": 1091,
                        "1e01": 1092,
                        "1e02": 1093,
                        "1e03": 1095,
                        "1f00": 1097,
                        "1f01": 1099,
                        "1f02": 1101,
                        "200000": 1004,
                        "200001": 1005,
                        "200002": 1006,
                        "200100": 1008,
                        "200101": 1100,
                        "200102": 1111,
                        "200200": 1113,
                        "200201": 1115,
                        "200202": 1116,
                        "200300": 1118,
                        "20030100": 1119,
                        "20030101": 1120,
                        "20030102": 1121,
                        "20030103": 1122,
                        "20030200": 1123,
                        "20030201": 1124,
                        "20030202": 1125,
                        "20030203": 1126,
                        "200400": 1128,
                        "200401": 1130,
                        "200402": 1131,
                        "2100": 1133,
                        "2101": 1135,
                        "2102": 1137,
                        "2200": 1139,
                        "220100": 1141,
                        "220101": 1142,
                        "2202": 1144,
                        "2203": 1146,
                        "2204": 1148,
                        "2205": 1150,
                        "2300": 1151,
                        "2301": 1153,
                        "2302": 1155,
                        "240000": 1157,
                        "240001": 1158,
                        "25": 1160,
                        "26": 1162,
                        "2700": 1163,
                        "2710": 1165,
                        "2711": 1167,
                        "2712": 1168,
                        "2713": 1169,
                        "2714": 1171,
                        "2715": 1173,
                        "2716": 1175,
                        "2717": 1177,
                        "2719": 1179,
                        "271a": 1181,
                        "271b": 1183,
                        "271c": 1185,
                        "271d": 1187,
                        "2720": 1189,
                        }
